You are viewing a plain text version of this content. The canonical link for it is here.
Posted to ivy-commits@incubator.apache.org by xa...@apache.org on 2007/01/07 10:41:36 UTC

svn commit: r493695 [5/7] - in /incubator/ivy/trunk: ./ doc/ doc/doc/ doc/doc/configuration/ doc/doc/ivyfile/ doc/doc/releasenotes/ doc/doc/use/ doc/samples/ doc/samples/multi-project/ doc/schemas/ doc/test/ src/example/build-a-ivy-repository/ src/exam...

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/resolver/URLLister.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/resolver/URLLister.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/resolver/URLLister.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/resolver/URLLister.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.resolver;
+package org.apache.ivy.resolver;
 
 import java.io.IOException;
 import java.net.URL;

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/resolver/URLResolver.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/resolver/URLResolver.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/resolver/URLResolver.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/resolver/URLResolver.java Sun Jan  7 02:41:19 2007
@@ -15,9 +15,9 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.resolver;
+package org.apache.ivy.resolver;
 
-import fr.jayasoft.ivy.repository.url.URLRepository;
+import org.apache.ivy.repository.url.URLRepository;
 
 /**
  * This resolver is able to work with any URLs, it handles latest revisions

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/resolver/VfsResolver.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/resolver/VfsResolver.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/resolver/VfsResolver.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/resolver/VfsResolver.java Sun Jan  7 02:41:19 2007
@@ -15,12 +15,13 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.resolver;
+package org.apache.ivy.resolver;
 
-import fr.jayasoft.ivy.repository.vfs.VfsRepository;
 
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
+
+import org.apache.ivy.repository.vfs.VfsRepository;
 
 /**
  * @author S. Nesbitt

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/resolver/VsftpResolver.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/resolver/VsftpResolver.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/resolver/VsftpResolver.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/resolver/VsftpResolver.java Sun Jan  7 02:41:19 2007
@@ -15,9 +15,9 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.resolver;
+package org.apache.ivy.resolver;
 
-import fr.jayasoft.ivy.repository.vsftp.VsftpRepository;
+import org.apache.ivy.repository.vsftp.VsftpRepository;
 
 /**
  * This resolver uses SecureCRT vsft to access an sftp server.

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/status/Status.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/status/Status.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/status/Status.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/status/Status.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.status;
+package org.apache.ivy.status;
 
 public class Status {
     private String _name;

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/status/StatusManager.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/status/StatusManager.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/status/StatusManager.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/status/StatusManager.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.status;
+package org.apache.ivy.status;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -25,8 +25,9 @@
 import java.util.ListIterator;
 import java.util.Map;
 
-import fr.jayasoft.ivy.Ivy;
-import fr.jayasoft.ivy.util.Message;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.util.Message;
+
 
 /**
  * Note: update methods (such as addStatus) should only be called BEFORE any call to accessor methods

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/DependencyAnalyser.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/DependencyAnalyser.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/DependencyAnalyser.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/DependencyAnalyser.java Sun Jan  7 02:41:19 2007
@@ -15,9 +15,9 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.tools.analyser;
+package org.apache.ivy.tools.analyser;
 
-import fr.jayasoft.ivy.ModuleDescriptor;
+import org.apache.ivy.ModuleDescriptor;
 
 public interface DependencyAnalyser {
 	public ModuleDescriptor[] analyze(JarModule[] modules);

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/JarJarDependencyAnalyser.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/JarJarDependencyAnalyser.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/JarJarDependencyAnalyser.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/JarJarDependencyAnalyser.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.tools.analyser;
+package org.apache.ivy.tools.analyser;
 
 import java.io.BufferedReader;
 import java.io.File;
@@ -25,10 +25,11 @@
 import java.util.HashMap;
 import java.util.Map;
 
-import fr.jayasoft.ivy.DefaultDependencyDescriptor;
-import fr.jayasoft.ivy.DefaultModuleDescriptor;
-import fr.jayasoft.ivy.ModuleDescriptor;
-import fr.jayasoft.ivy.util.Message;
+import org.apache.ivy.DefaultDependencyDescriptor;
+import org.apache.ivy.DefaultModuleDescriptor;
+import org.apache.ivy.ModuleDescriptor;
+import org.apache.ivy.util.Message;
+
 
 public class JarJarDependencyAnalyser implements DependencyAnalyser {
 	private File _jarjarjarLocation;

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/JarModule.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/JarModule.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/JarModule.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/JarModule.java Sun Jan  7 02:41:19 2007
@@ -15,11 +15,12 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.tools.analyser;
+package org.apache.ivy.tools.analyser;
 
 import java.io.File;
 
-import fr.jayasoft.ivy.ModuleRevisionId;
+import org.apache.ivy.ModuleRevisionId;
+
 
 public class JarModule {
 	private ModuleRevisionId _mrid;

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/JarModuleFinder.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/JarModuleFinder.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/JarModuleFinder.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/JarModuleFinder.java Sun Jan  7 02:41:19 2007
@@ -15,17 +15,18 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.tools.analyser;
+package org.apache.ivy.tools.analyser;
 
 import java.io.File;
 import java.util.ArrayList;
 import java.util.List;
 
-import fr.jayasoft.ivy.ModuleRevisionId;
-import fr.jayasoft.ivy.resolver.FileURLLister;
-import fr.jayasoft.ivy.resolver.ResolverHelper;
-import fr.jayasoft.ivy.resolver.URLLister;
-import fr.jayasoft.ivy.util.IvyPatternHelper;
+import org.apache.ivy.ModuleRevisionId;
+import org.apache.ivy.resolver.FileURLLister;
+import org.apache.ivy.resolver.ResolverHelper;
+import org.apache.ivy.resolver.URLLister;
+import org.apache.ivy.util.IvyPatternHelper;
+
 
 public class JarModuleFinder {
 	private String _pattern;

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/RepositoryAnalyser.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/RepositoryAnalyser.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/RepositoryAnalyser.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/tools/analyser/RepositoryAnalyser.java Sun Jan  7 02:41:19 2007
@@ -15,16 +15,17 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.tools.analyser;
+package org.apache.ivy.tools.analyser;
 
 import java.io.File;
 import java.io.IOException;
 
-import fr.jayasoft.ivy.DefaultArtifact;
-import fr.jayasoft.ivy.ModuleDescriptor;
-import fr.jayasoft.ivy.util.IvyPatternHelper;
-import fr.jayasoft.ivy.util.Message;
-import fr.jayasoft.ivy.xml.XmlModuleDescriptorWriter;
+import org.apache.ivy.DefaultArtifact;
+import org.apache.ivy.ModuleDescriptor;
+import org.apache.ivy.util.IvyPatternHelper;
+import org.apache.ivy.util.Message;
+import org.apache.ivy.xml.XmlModuleDescriptorWriter;
+
 
 public class RepositoryAnalyser {
 	public void analyse(String pattern, DependencyAnalyser depAnalyser) {

Copied: incubator/ivy/trunk/src/java/org/apache/ivy/typedef.properties (from r493681, incubator/ivy/trunk/src/java/fr/jayasoft/ivy/typedef.properties)
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/typedef.properties?view=diff&rev=493695&p1=incubator/ivy/trunk/src/java/fr/jayasoft/ivy/typedef.properties&r1=493681&p2=incubator/ivy/trunk/src/java/org/apache/ivy/typedef.properties&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/fr/jayasoft/ivy/typedef.properties (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/typedef.properties Sun Jan  7 02:41:19 2007
@@ -1,33 +1,33 @@
-filesystem 	= fr.jayasoft.ivy.resolver.FileSystemResolver
-chain 		= fr.jayasoft.ivy.resolver.ChainResolver
-ibiblio		= fr.jayasoft.ivy.resolver.IBiblioResolver
-url			= fr.jayasoft.ivy.resolver.URLResolver
-dual		= fr.jayasoft.ivy.resolver.DualResolver
-ivyrep		= fr.jayasoft.ivy.resolver.IvyRepResolver
-ssh         = fr.jayasoft.ivy.resolver.SshResolver
-sftp        = fr.jayasoft.ivy.resolver.SFTPResolver
-vsftp       = fr.jayasoft.ivy.resolver.VsftpResolver
-vfs         = fr.jayasoft.ivy.resolver.VfsResolver
-cache		= fr.jayasoft.ivy.resolver.CacheResolver
-
-latest-revision = fr.jayasoft.ivy.latest.LatestRevisionStrategy
-latest-lexico   = fr.jayasoft.ivy.latest.LatestLexicographicStrategy
-latest-time     = fr.jayasoft.ivy.latest.LatestTimeStrategy
-
-fixed-cm 	= fr.jayasoft.ivy.conflict.FixedConflictManager
-latest-cm   = fr.jayasoft.ivy.conflict.LatestConflictManager
-no-cm     	= fr.jayasoft.ivy.conflict.NoConflictManager
-strict-cm   = fr.jayasoft.ivy.conflict.StrictConflictManager
-regexp-cm   = fr.jayasoft.ivy.conflict.RegexpConflictManager
-
-
-namespace   = fr.jayasoft.ivy.namespace.Namespace
-
-exact-vm		= fr.jayasoft.ivy.version.ExactVersionMatcher
-chain-vm		= fr.jayasoft.ivy.version.ChainVersionMatcher
-latest-vm  		= fr.jayasoft.ivy.version.LatestVersionMatcher
-sub-vm  		= fr.jayasoft.ivy.version.SubVersionMatcher
-range-vm		= fr.jayasoft.ivy.version.VersionRangeMatcher
+filesystem 	= org.apache.ivy.resolver.FileSystemResolver
+chain 		= org.apache.ivy.resolver.ChainResolver
+ibiblio		= org.apache.ivy.resolver.IBiblioResolver
+url			= org.apache.ivy.resolver.URLResolver
+dual		= org.apache.ivy.resolver.DualResolver
+ivyrep		= org.apache.ivy.resolver.IvyRepResolver
+ssh         = org.apache.ivy.resolver.SshResolver
+sftp        = org.apache.ivy.resolver.SFTPResolver
+vsftp       = org.apache.ivy.resolver.VsftpResolver
+vfs         = org.apache.ivy.resolver.VfsResolver
+cache		= org.apache.ivy.resolver.CacheResolver
+
+latest-revision = org.apache.ivy.latest.LatestRevisionStrategy
+latest-lexico   = org.apache.ivy.latest.LatestLexicographicStrategy
+latest-time     = org.apache.ivy.latest.LatestTimeStrategy
+
+fixed-cm 	= org.apache.ivy.conflict.FixedConflictManager
+latest-cm   = org.apache.ivy.conflict.LatestConflictManager
+no-cm     	= org.apache.ivy.conflict.NoConflictManager
+strict-cm   = org.apache.ivy.conflict.StrictConflictManager
+regexp-cm   = org.apache.ivy.conflict.RegexpConflictManager
+
+
+namespace   = org.apache.ivy.namespace.Namespace
+
+exact-vm		= org.apache.ivy.version.ExactVersionMatcher
+chain-vm		= org.apache.ivy.version.ChainVersionMatcher
+latest-vm  		= org.apache.ivy.version.LatestVersionMatcher
+sub-vm  		= org.apache.ivy.version.SubVersionMatcher
+range-vm		= org.apache.ivy.version.VersionRangeMatcher
 
-ant-build		= fr.jayasoft.ivy.ant.AntBuildTrigger
-ant-call		= fr.jayasoft.ivy.ant.AntCallTrigger
+ant-build		= org.apache.ivy.ant.AntBuildTrigger
+ant-call		= org.apache.ivy.ant.AntCallTrigger

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/url/AbstractURLHandler.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/url/AbstractURLHandler.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/url/AbstractURLHandler.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/url/AbstractURLHandler.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.url;
+package org.apache.ivy.url;
 
 import java.net.URL;
 

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/url/ApacheURLLister.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/url/ApacheURLLister.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/url/ApacheURLLister.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/url/ApacheURLLister.java Sun Jan  7 02:41:19 2007
@@ -15,10 +15,8 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.url;
+package org.apache.ivy.url;
 
-import fr.jayasoft.ivy.util.FileUtil;
-import fr.jayasoft.ivy.util.Message;
 
 import java.io.BufferedReader;
 import java.io.IOException;
@@ -28,6 +26,9 @@
 import java.util.List;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
+
+import org.apache.ivy.util.FileUtil;
+import org.apache.ivy.util.Message;
 
 
 /**

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/url/BasicURLHandler.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/url/BasicURLHandler.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/url/BasicURLHandler.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/url/BasicURLHandler.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.url;
+package org.apache.ivy.url;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -27,9 +27,10 @@
 import java.net.URLConnection;
 import java.net.UnknownHostException;
 
-import fr.jayasoft.ivy.util.CopyProgressListener;
-import fr.jayasoft.ivy.util.FileUtil;
-import fr.jayasoft.ivy.util.Message;
+import org.apache.ivy.util.CopyProgressListener;
+import org.apache.ivy.util.FileUtil;
+import org.apache.ivy.util.Message;
+
 
 /**
  * @author Xavier Hanin

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/url/CredentialsStore.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/url/CredentialsStore.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/url/CredentialsStore.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/url/CredentialsStore.java Sun Jan  7 02:41:19 2007
@@ -15,13 +15,14 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.url;
+package org.apache.ivy.url;
 
 import java.util.HashMap;
 import java.util.Map;
 
-import fr.jayasoft.ivy.util.Credentials;
-import fr.jayasoft.ivy.util.Message;
+import org.apache.ivy.util.Credentials;
+import org.apache.ivy.util.Message;
+
 
 /**
  * 

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/url/HttpClientHandler.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/url/HttpClientHandler.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/url/HttpClientHandler.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/url/HttpClientHandler.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.url;
+package org.apache.ivy.url;
 
 import java.io.File;
 import java.io.IOException;
@@ -37,11 +37,11 @@
 import org.apache.commons.httpclient.auth.AuthPolicy;
 import org.apache.commons.httpclient.methods.GetMethod;
 import org.apache.commons.httpclient.methods.HeadMethod;
+import org.apache.ivy.util.CopyProgressListener;
+import org.apache.ivy.util.Credentials;
+import org.apache.ivy.util.FileUtil;
+import org.apache.ivy.util.Message;
 
-import fr.jayasoft.ivy.util.CopyProgressListener;
-import fr.jayasoft.ivy.util.Credentials;
-import fr.jayasoft.ivy.util.FileUtil;
-import fr.jayasoft.ivy.util.Message;
 
 /**
  * @author Xavier Hanin

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/url/IvyAuthenticator.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/url/IvyAuthenticator.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/url/IvyAuthenticator.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/url/IvyAuthenticator.java Sun Jan  7 02:41:19 2007
@@ -15,13 +15,14 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.url;
+package org.apache.ivy.url;
 
 import java.net.Authenticator;
 import java.net.PasswordAuthentication;
 
-import fr.jayasoft.ivy.util.Credentials;
-import fr.jayasoft.ivy.util.Message;
+import org.apache.ivy.util.Credentials;
+import org.apache.ivy.util.Message;
+
 
 /**
  * 

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/url/URLHandler.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/url/URLHandler.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/url/URLHandler.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/url/URLHandler.java Sun Jan  7 02:41:19 2007
@@ -15,14 +15,15 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.url;
+package org.apache.ivy.url;
 
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
 
-import fr.jayasoft.ivy.util.CopyProgressListener;
+import org.apache.ivy.util.CopyProgressListener;
+
 
 /**
  * This interface is responsible for handling some URL manipulation

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/url/URLHandlerDispatcher.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/url/URLHandlerDispatcher.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/url/URLHandlerDispatcher.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/url/URLHandlerDispatcher.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.url;
+package org.apache.ivy.url;
 
 import java.io.File;
 import java.io.IOException;
@@ -24,7 +24,8 @@
 import java.util.HashMap;
 import java.util.Map;
 
-import fr.jayasoft.ivy.util.CopyProgressListener;
+import org.apache.ivy.util.CopyProgressListener;
+
 
 /**
  * This class is used to dispatch downloading requests

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/url/URLHandlerRegistry.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/url/URLHandlerRegistry.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/url/URLHandlerRegistry.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/url/URLHandlerRegistry.java Sun Jan  7 02:41:19 2007
@@ -15,9 +15,9 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.url;
+package org.apache.ivy.url;
 
-import fr.jayasoft.ivy.util.Message;
+import org.apache.ivy.util.Message;
 
 /**
  * @author Xavier Hanin

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/ChecksumHelper.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/ChecksumHelper.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/ChecksumHelper.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/ChecksumHelper.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 import java.io.BufferedReader;
 import java.io.File;

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/Configurator.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/Configurator.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/Configurator.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/Configurator.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/CopyProgressEvent.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/CopyProgressEvent.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/CopyProgressEvent.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/CopyProgressEvent.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 /**
  * Event reporting a stream copy progression

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/CopyProgressListener.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/CopyProgressListener.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/CopyProgressListener.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/CopyProgressListener.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 /**
  * Listen to copy progression

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/Credentials.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/Credentials.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/Credentials.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/Credentials.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 /**
  * 

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/CredentialsUtil.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/CredentialsUtil.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/CredentialsUtil.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/CredentialsUtil.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
@@ -34,7 +34,8 @@
 import javax.swing.JPasswordField;
 import javax.swing.JTextField;
 
-import fr.jayasoft.ivy.Ivy;
+import org.apache.ivy.Ivy;
+
 
 public class CredentialsUtil {
 	

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/DefaultMessageImpl.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/DefaultMessageImpl.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/DefaultMessageImpl.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/DefaultMessageImpl.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 public class DefaultMessageImpl implements MessageImpl {
     private int _level = Message.MSG_INFO;

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/EncrytedProperties.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/EncrytedProperties.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/EncrytedProperties.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/EncrytedProperties.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 import java.util.ArrayList;
 import java.util.Collection;

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/FileUtil.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/FileUtil.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/FileUtil.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/FileUtil.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 import java.io.BufferedReader;
 import java.io.File;
@@ -33,7 +33,8 @@
 import java.util.Collections;
 import java.util.List;
 
-import fr.jayasoft.ivy.url.URLHandlerRegistry;
+import org.apache.ivy.url.URLHandlerRegistry;
+
 
 
 /**

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/IvyPattern.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/IvyPattern.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/IvyPattern.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/IvyPattern.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 /**
  * @author x.hanin

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/IvyPatternHelper.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/IvyPatternHelper.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/IvyPatternHelper.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/IvyPatternHelper.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 import java.io.File;
 import java.util.ArrayList;
@@ -27,12 +27,13 @@
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import fr.jayasoft.ivy.Artifact;
-import fr.jayasoft.ivy.ArtifactOrigin;
-import fr.jayasoft.ivy.DefaultArtifact;
-import fr.jayasoft.ivy.Ivy;
-import fr.jayasoft.ivy.IvyContext;
-import fr.jayasoft.ivy.ModuleRevisionId;
+import org.apache.ivy.Artifact;
+import org.apache.ivy.ArtifactOrigin;
+import org.apache.ivy.DefaultArtifact;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.IvyContext;
+import org.apache.ivy.ModuleRevisionId;
+
 
 /**
  * @author x.hanin
@@ -335,7 +336,7 @@
     public static void main(String[] args) {
         String pattern = "[organisation]/[module]/build/archives/[type]s/[artifact]-[revision].[ext]";
         System.out.println("pattern= "+pattern);
-        System.out.println("resolved= "+substitute(pattern, "jayasoft", "Test", "1.0", "test", "jar", "jar"));
+        System.out.println("resolved= "+substitute(pattern, "apache", "Test", "1.0", "test", "jar", "jar"));
         
         Map variables = new HashMap();
         variables.put("test", "mytest");

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/IvyThread.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/IvyThread.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/IvyThread.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/IvyThread.java Sun Jan  7 02:41:19 2007
@@ -15,9 +15,9 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
-import fr.jayasoft.ivy.IvyContext;
+import org.apache.ivy.IvyContext;
 
 /**
  * A simple thread subclass associated the same IvyContext as the thread in which it is instanciated.

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/Message.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/Message.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/Message.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/Message.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -25,7 +25,8 @@
 import java.util.List;
 import java.util.Properties;
 
-import fr.jayasoft.ivy.IvyContext;
+import org.apache.ivy.IvyContext;
+
 
 /**
  * 
@@ -84,13 +85,13 @@
                 	InputStream module = moduleURL.openStream();
                     props.load(module);
                     debug("version information loaded from "+moduleURL);
-                    info(":: Ivy "+props.getProperty("version")+" - "+props.getProperty("date")+" :: http://ivy.jayasoft.org/ ::");
+                    info(":: Ivy "+props.getProperty("version")+" - "+props.getProperty("date")+" :: http://incubator.apache.org/ivy/ ::");
                     module.close();
                 } catch (IOException e) {
-                    info(":: Ivy non official version :: http://ivy.jayasoft.org/ ::");
+                    info(":: Ivy non official version :: http://incubator.apache.org/ivy/ ::");
                 }
             } else {
-                info(":: Ivy non official version :: http://ivy.jayasoft.org/ ::");
+                info(":: Ivy non official version :: http://incubator.apache.org/ivy/ ::");
             }
             _showedInfo = true;
         }

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/MessageImpl.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/MessageImpl.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/MessageImpl.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/MessageImpl.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 public interface MessageImpl {
     public void log(String msg, int level);

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/PropertiesFile.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/PropertiesFile.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/PropertiesFile.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/PropertiesFile.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 import java.io.File;
 import java.io.FileInputStream;

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/StringUtils.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/StringUtils.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/StringUtils.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/StringUtils.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 import java.util.Arrays;
 import java.util.HashSet;

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/util/XMLHelper.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/util/XMLHelper.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/util/XMLHelper.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/util/XMLHelper.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.util;
+package org.apache.ivy.util;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -25,12 +25,12 @@
 import javax.xml.parsers.SAXParser;
 import javax.xml.parsers.SAXParserFactory;
 
+import org.apache.ivy.url.URLHandlerRegistry;
 import org.xml.sax.SAXException;
 import org.xml.sax.SAXNotRecognizedException;
 import org.xml.sax.ext.LexicalHandler;
 import org.xml.sax.helpers.DefaultHandler;
 
-import fr.jayasoft.ivy.url.URLHandlerRegistry;
 
 public abstract class XMLHelper {
     private static SAXParserFactory _validatingFactory = SAXParserFactory.newInstance();

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/version/AbstractVersionMatcher.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/version/AbstractVersionMatcher.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/version/AbstractVersionMatcher.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/version/AbstractVersionMatcher.java Sun Jan  7 02:41:19 2007
@@ -15,12 +15,12 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.version;
+package org.apache.ivy.version;
 
-import fr.jayasoft.ivy.Ivy;
-import fr.jayasoft.ivy.IvyAware;
-import fr.jayasoft.ivy.ModuleDescriptor;
-import fr.jayasoft.ivy.ModuleRevisionId;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.IvyAware;
+import org.apache.ivy.ModuleDescriptor;
+import org.apache.ivy.ModuleRevisionId;
 
 public abstract class AbstractVersionMatcher implements VersionMatcher, IvyAware {
 	private String _name;

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/version/ChainVersionMatcher.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/version/ChainVersionMatcher.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/version/ChainVersionMatcher.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/version/ChainVersionMatcher.java Sun Jan  7 02:41:19 2007
@@ -15,17 +15,18 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.version;
+package org.apache.ivy.version;
 
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 
-import fr.jayasoft.ivy.Ivy;
-import fr.jayasoft.ivy.IvyAware;
-import fr.jayasoft.ivy.ModuleDescriptor;
-import fr.jayasoft.ivy.ModuleRevisionId;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.IvyAware;
+import org.apache.ivy.ModuleDescriptor;
+import org.apache.ivy.ModuleRevisionId;
+
 
 public class ChainVersionMatcher extends AbstractVersionMatcher {
     private List _matchers = new LinkedList();

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/version/ExactVersionMatcher.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/version/ExactVersionMatcher.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/version/ExactVersionMatcher.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/version/ExactVersionMatcher.java Sun Jan  7 02:41:19 2007
@@ -15,9 +15,9 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.version;
+package org.apache.ivy.version;
 
-import fr.jayasoft.ivy.ModuleRevisionId;
+import org.apache.ivy.ModuleRevisionId;
 
 public class ExactVersionMatcher extends AbstractVersionMatcher {
 

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/version/LatestVersionMatcher.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/version/LatestVersionMatcher.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/version/LatestVersionMatcher.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/version/LatestVersionMatcher.java Sun Jan  7 02:41:19 2007
@@ -15,11 +15,11 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.version;
+package org.apache.ivy.version;
 
-import fr.jayasoft.ivy.ModuleDescriptor;
-import fr.jayasoft.ivy.ModuleRevisionId;
-import fr.jayasoft.ivy.status.StatusManager;
+import org.apache.ivy.ModuleDescriptor;
+import org.apache.ivy.ModuleRevisionId;
+import org.apache.ivy.status.StatusManager;
 
 public class LatestVersionMatcher  extends AbstractVersionMatcher {
 	public LatestVersionMatcher() {

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/version/Match.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/version/Match.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/version/Match.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/version/Match.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.version;
+package org.apache.ivy.version;
 
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -23,11 +23,12 @@
 import java.util.Map;
 import java.util.StringTokenizer;
 
-import fr.jayasoft.ivy.Ivy;
-import fr.jayasoft.ivy.ModuleRevisionId;
-import fr.jayasoft.ivy.matcher.Matcher;
-import fr.jayasoft.ivy.matcher.PatternMatcher;
-import fr.jayasoft.ivy.util.IvyPatternHelper;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.ModuleRevisionId;
+import org.apache.ivy.matcher.Matcher;
+import org.apache.ivy.matcher.PatternMatcher;
+import org.apache.ivy.util.IvyPatternHelper;
+
 
 
 /**

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/version/PatternVersionMatcher.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/version/PatternVersionMatcher.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/version/PatternVersionMatcher.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/version/PatternVersionMatcher.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.version;
+package org.apache.ivy.version;
 
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -23,9 +23,10 @@
 import java.util.List;
 import java.util.Map;
 
-import fr.jayasoft.ivy.ModuleRevisionId;
-import fr.jayasoft.ivy.matcher.Matcher;
-import fr.jayasoft.ivy.version.AbstractVersionMatcher;
+import org.apache.ivy.ModuleRevisionId;
+import org.apache.ivy.matcher.Matcher;
+import org.apache.ivy.version.AbstractVersionMatcher;
+
 
 /**
  * 

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/version/SubVersionMatcher.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/version/SubVersionMatcher.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/version/SubVersionMatcher.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/version/SubVersionMatcher.java Sun Jan  7 02:41:19 2007
@@ -15,9 +15,9 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.version;
+package org.apache.ivy.version;
 
-import fr.jayasoft.ivy.ModuleRevisionId;
+import org.apache.ivy.ModuleRevisionId;
 
 public class SubVersionMatcher  extends AbstractVersionMatcher {
 	public SubVersionMatcher() {

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/version/VersionMatcher.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/version/VersionMatcher.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/version/VersionMatcher.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/version/VersionMatcher.java Sun Jan  7 02:41:19 2007
@@ -15,10 +15,10 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.version;
+package org.apache.ivy.version;
 
-import fr.jayasoft.ivy.ModuleDescriptor;
-import fr.jayasoft.ivy.ModuleRevisionId;
+import org.apache.ivy.ModuleDescriptor;
+import org.apache.ivy.ModuleRevisionId;
 
 /**
  * This interface defines a version matcher, i.e. a class able to tell if the revision

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/version/VersionRangeMatcher.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/version/VersionRangeMatcher.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/version/VersionRangeMatcher.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/version/VersionRangeMatcher.java Sun Jan  7 02:41:19 2007
@@ -15,17 +15,18 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.version;
+package org.apache.ivy.version;
 
 import java.util.Comparator;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import fr.jayasoft.ivy.ArtifactInfo;
-import fr.jayasoft.ivy.Ivy;
-import fr.jayasoft.ivy.IvyAware;
-import fr.jayasoft.ivy.LatestStrategy;
-import fr.jayasoft.ivy.ModuleRevisionId;
+import org.apache.ivy.ArtifactInfo;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.IvyAware;
+import org.apache.ivy.LatestStrategy;
+import org.apache.ivy.ModuleRevisionId;
+
 
 /**
  * Matches version ranges:

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlIvyConfigurationParser.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlIvyConfigurationParser.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlIvyConfigurationParser.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlIvyConfigurationParser.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.xml;
+package org.apache.ivy.xml;
 
 import java.io.File;
 import java.io.IOException;
@@ -30,20 +30,20 @@
 
 import javax.xml.parsers.SAXParserFactory;
 
+import org.apache.ivy.ConflictManager;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.LatestStrategy;
+import org.apache.ivy.ModuleId;
+import org.apache.ivy.circular.CircularDependencyStrategy;
+import org.apache.ivy.matcher.PatternMatcher;
+import org.apache.ivy.status.StatusManager;
+import org.apache.ivy.url.URLHandlerRegistry;
+import org.apache.ivy.util.Configurator;
+import org.apache.ivy.util.Message;
 import org.xml.sax.Attributes;
 import org.xml.sax.SAXException;
 import org.xml.sax.helpers.DefaultHandler;
 
-import fr.jayasoft.ivy.ConflictManager;
-import fr.jayasoft.ivy.Ivy;
-import fr.jayasoft.ivy.LatestStrategy;
-import fr.jayasoft.ivy.ModuleId;
-import fr.jayasoft.ivy.circular.CircularDependencyStrategy;
-import fr.jayasoft.ivy.matcher.PatternMatcher;
-import fr.jayasoft.ivy.status.StatusManager;
-import fr.jayasoft.ivy.url.URLHandlerRegistry;
-import fr.jayasoft.ivy.util.Configurator;
-import fr.jayasoft.ivy.util.Message;
 
 /**
  * @author Hanin

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlModuleDescriptorParser.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlModuleDescriptorParser.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlModuleDescriptorParser.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlModuleDescriptorParser.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.xml;
+package org.apache.ivy.xml;
 
 import java.io.File;
 import java.io.IOException;
@@ -29,31 +29,31 @@
 
 import javax.xml.parsers.ParserConfigurationException;
 
+import org.apache.ivy.ArtifactId;
+import org.apache.ivy.Configuration;
+import org.apache.ivy.ConflictManager;
+import org.apache.ivy.DefaultDependencyArtifactDescriptor;
+import org.apache.ivy.DefaultDependencyDescriptor;
+import org.apache.ivy.DefaultModuleDescriptor;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.License;
+import org.apache.ivy.MDArtifact;
+import org.apache.ivy.ModuleDescriptor;
+import org.apache.ivy.ModuleId;
+import org.apache.ivy.ModuleRevisionId;
+import org.apache.ivy.conflict.FixedConflictManager;
+import org.apache.ivy.extendable.ExtendableItemHelper;
+import org.apache.ivy.matcher.PatternMatcher;
+import org.apache.ivy.namespace.Namespace;
+import org.apache.ivy.parser.AbstractModuleDescriptorParser;
+import org.apache.ivy.parser.ModuleDescriptorParser;
+import org.apache.ivy.repository.Resource;
+import org.apache.ivy.repository.url.URLResource;
+import org.apache.ivy.util.Message;
+import org.apache.ivy.util.XMLHelper;
 import org.xml.sax.Attributes;
 import org.xml.sax.SAXException;
 
-import fr.jayasoft.ivy.ArtifactId;
-import fr.jayasoft.ivy.Configuration;
-import fr.jayasoft.ivy.ConflictManager;
-import fr.jayasoft.ivy.DefaultDependencyArtifactDescriptor;
-import fr.jayasoft.ivy.DefaultDependencyDescriptor;
-import fr.jayasoft.ivy.DefaultModuleDescriptor;
-import fr.jayasoft.ivy.Ivy;
-import fr.jayasoft.ivy.License;
-import fr.jayasoft.ivy.MDArtifact;
-import fr.jayasoft.ivy.ModuleDescriptor;
-import fr.jayasoft.ivy.ModuleId;
-import fr.jayasoft.ivy.ModuleRevisionId;
-import fr.jayasoft.ivy.conflict.FixedConflictManager;
-import fr.jayasoft.ivy.extendable.ExtendableItemHelper;
-import fr.jayasoft.ivy.matcher.PatternMatcher;
-import fr.jayasoft.ivy.namespace.Namespace;
-import fr.jayasoft.ivy.parser.AbstractModuleDescriptorParser;
-import fr.jayasoft.ivy.parser.ModuleDescriptorParser;
-import fr.jayasoft.ivy.repository.Resource;
-import fr.jayasoft.ivy.repository.url.URLResource;
-import fr.jayasoft.ivy.util.Message;
-import fr.jayasoft.ivy.util.XMLHelper;
 
 /**
  * Parses an xml ivy file and output a ModuleDescriptor.

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlModuleDescriptorUpdater.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlModuleDescriptorUpdater.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlModuleDescriptorUpdater.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlModuleDescriptorUpdater.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.xml;
+package org.apache.ivy.xml;
 
 import java.io.BufferedInputStream;
 import java.io.BufferedReader;
@@ -36,17 +36,17 @@
 
 import javax.xml.parsers.ParserConfigurationException;
 
+import org.apache.ivy.Ivy;
+import org.apache.ivy.ModuleRevisionId;
+import org.apache.ivy.namespace.Namespace;
+import org.apache.ivy.util.Message;
+import org.apache.ivy.util.XMLHelper;
 import org.xml.sax.Attributes;
 import org.xml.sax.SAXException;
 import org.xml.sax.SAXParseException;
 import org.xml.sax.ext.LexicalHandler;
 import org.xml.sax.helpers.DefaultHandler;
 
-import fr.jayasoft.ivy.Ivy;
-import fr.jayasoft.ivy.ModuleRevisionId;
-import fr.jayasoft.ivy.namespace.Namespace;
-import fr.jayasoft.ivy.util.Message;
-import fr.jayasoft.ivy.util.XMLHelper;
 
 /**
  * Used to update ivy files. Uses ivy file as source and not ModuleDescriptor to preserve

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlModuleDescriptorWriter.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlModuleDescriptorWriter.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlModuleDescriptorWriter.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlModuleDescriptorWriter.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.xml;
+package org.apache.ivy.xml;
 
 import java.io.File;
 import java.io.FileOutputStream;
@@ -26,13 +26,14 @@
 import java.util.Collection;
 import java.util.HashSet;
 
-import fr.jayasoft.ivy.Artifact;
-import fr.jayasoft.ivy.Configuration;
-import fr.jayasoft.ivy.DefaultModuleDescriptor;
-import fr.jayasoft.ivy.DependencyArtifactDescriptor;
-import fr.jayasoft.ivy.DependencyDescriptor;
-import fr.jayasoft.ivy.Ivy;
-import fr.jayasoft.ivy.ModuleDescriptor;
+import org.apache.ivy.Artifact;
+import org.apache.ivy.Configuration;
+import org.apache.ivy.DefaultModuleDescriptor;
+import org.apache.ivy.DependencyArtifactDescriptor;
+import org.apache.ivy.DependencyDescriptor;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.ModuleDescriptor;
+
 
 /**
  * @author Xavier Hanin

Modified: incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlReportParser.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlReportParser.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlReportParser.java (original)
+++ incubator/ivy/trunk/src/java/org/apache/ivy/xml/XmlReportParser.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.xml;
+package org.apache.ivy.xml;
 
 import java.io.File;
 import java.io.IOException;
@@ -30,17 +30,17 @@
 import javax.xml.parsers.SAXParser;
 import javax.xml.parsers.SAXParserFactory;
 
+import org.apache.ivy.Artifact;
+import org.apache.ivy.DefaultArtifact;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.ModuleId;
+import org.apache.ivy.ModuleRevisionId;
+import org.apache.ivy.extendable.ExtendableItemHelper;
+import org.apache.ivy.report.XmlReportOutputter;
 import org.xml.sax.Attributes;
 import org.xml.sax.SAXException;
 import org.xml.sax.helpers.DefaultHandler;
 
-import fr.jayasoft.ivy.Artifact;
-import fr.jayasoft.ivy.DefaultArtifact;
-import fr.jayasoft.ivy.Ivy;
-import fr.jayasoft.ivy.ModuleId;
-import fr.jayasoft.ivy.ModuleRevisionId;
-import fr.jayasoft.ivy.extendable.ExtendableItemHelper;
-import fr.jayasoft.ivy.report.XmlReportOutputter;
 
 public class XmlReportParser {
     private static class SaxXmlReportParser {

Modified: incubator/ivy/trunk/test/buildlist/A/ivy.xml
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/buildlist/A/ivy.xml?view=diff&rev=493695&r1=493694&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/buildlist/A/ivy.xml (original)
+++ incubator/ivy/trunk/test/buildlist/A/ivy.xml Sun Jan  7 02:41:19 2007
@@ -1,5 +1,5 @@
 <ivy-module version="1.2">
-	<info organisation="jayasoft" module="A"/>
+	<info organisation="apache" module="A"/>
 	<dependencies>
 		<dependency name="C" rev="latest.integration"/>
 	</dependencies>

Modified: incubator/ivy/trunk/test/buildlist/B/ivy.xml
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/buildlist/B/ivy.xml?view=diff&rev=493695&r1=493694&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/buildlist/B/ivy.xml (original)
+++ incubator/ivy/trunk/test/buildlist/B/ivy.xml Sun Jan  7 02:41:19 2007
@@ -1,3 +1,3 @@
 <ivy-module version="1.2">
-	<info organisation="jayasoft" module="B"/>
+	<info organisation="apache" module="B"/>
 </ivy-module>

Modified: incubator/ivy/trunk/test/buildlist/C/ivy.xml
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/buildlist/C/ivy.xml?view=diff&rev=493695&r1=493694&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/buildlist/C/ivy.xml (original)
+++ incubator/ivy/trunk/test/buildlist/C/ivy.xml Sun Jan  7 02:41:19 2007
@@ -1,5 +1,5 @@
 <ivy-module version="1.2">
-	<info organisation="jayasoft" module="C"/>
+	<info organisation="apache" module="C"/>
 	<dependencies>
 		<dependency name="B" rev="latest.integration"/>
 	</dependencies>

Modified: incubator/ivy/trunk/test/buildlist/D/ivy.xml
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/buildlist/D/ivy.xml?view=diff&rev=493695&r1=493694&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/buildlist/D/ivy.xml (original)
+++ incubator/ivy/trunk/test/buildlist/D/ivy.xml Sun Jan  7 02:41:19 2007
@@ -1,5 +1,5 @@
 <ivy-module version="1.2">
-	<info organisation="jayasoft" module="D"/>
+	<info organisation="apache" module="D"/>
 	<dependencies>
 		<dependency name="A" rev="latest.integration"/>
 		<dependency name="B" rev="latest.integration"/>

Modified: incubator/ivy/trunk/test/buildlist/E/ivy.xml
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/buildlist/E/ivy.xml?view=diff&rev=493695&r1=493694&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/buildlist/E/ivy.xml (original)
+++ incubator/ivy/trunk/test/buildlist/E/ivy.xml Sun Jan  7 02:41:19 2007
@@ -1,3 +1,3 @@
 <ivy-module version="1.2">
-	<info organisation="jayasoft" module="E"/>
+	<info organisation="apache" module="E"/>
 </ivy-module>

Copied: incubator/ivy/trunk/test/java/org/apache/ivy/ConfigureTest.java (from r493681, incubator/ivy/trunk/test/java/fr/jayasoft/ivy/ConfigureTest.java)
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/ConfigureTest.java?view=diff&rev=493695&p1=incubator/ivy/trunk/test/java/fr/jayasoft/ivy/ConfigureTest.java&r1=493681&p2=incubator/ivy/trunk/test/java/org/apache/ivy/ConfigureTest.java&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/fr/jayasoft/ivy/ConfigureTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/ConfigureTest.java Sun Jan  7 02:41:19 2007
@@ -15,12 +15,15 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy;
+package org.apache.ivy;
 
 import java.io.File;
 import java.io.IOException;
 import java.text.ParseException;
 
+import org.apache.ivy.DependencyResolver;
+import org.apache.ivy.Ivy;
+
 import junit.framework.TestCase;
 
 public class ConfigureTest extends TestCase {
@@ -33,22 +36,22 @@
     
     public void testTypedefWithCustomClasspath() throws Exception {
         Ivy ivy = new Ivy();
-        ivy.setVariable("ivy.custom.test.dir", new File("test/java/fr/jayasoft/ivy").toURL().toString());
+        ivy.setVariable("ivy.custom.test.dir", new File("test/java/org/apache/ivy").toURL().toString());
         ivy.configure(ConfigureTest.class.getResource("ivyconf-custom-typedef.xml"));
         
         DependencyResolver custom = ivy.getResolver("custom");
         assertNotNull(custom);
-        assertEquals("fr.jayasoft.ivy.resolver.CustomResolver", custom.getClass().getName());
+        assertEquals("org.apache.ivy.resolver.CustomResolver", custom.getClass().getName());
     }
 
     public void testTypedefWithCustomClasspathWithFile() throws Exception {
         Ivy ivy = new Ivy();
-        ivy.setVariable("ivy.custom.test.dir", new File("test/java/fr/jayasoft/ivy").toString());
+        ivy.setVariable("ivy.custom.test.dir", new File("test/java/org/apache/ivy").toString());
         ivy.configure(ConfigureTest.class.getResource("ivyconf-custom-typedef2.xml"));
         
         DependencyResolver custom = ivy.getResolver("custom");
         assertNotNull(custom);
-        assertEquals("fr.jayasoft.ivy.resolver.CustomResolver", custom.getClass().getName());
+        assertEquals("org.apache.ivy.resolver.CustomResolver", custom.getClass().getName());
     }
 
 }

Copied: incubator/ivy/trunk/test/java/org/apache/ivy/DefaultDependencyDescriptorTest.java (from r493681, incubator/ivy/trunk/test/java/fr/jayasoft/ivy/DefaultDependencyDescriptorTest.java)
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/DefaultDependencyDescriptorTest.java?view=diff&rev=493695&p1=incubator/ivy/trunk/test/java/fr/jayasoft/ivy/DefaultDependencyDescriptorTest.java&r1=493681&p2=incubator/ivy/trunk/test/java/org/apache/ivy/DefaultDependencyDescriptorTest.java&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/fr/jayasoft/ivy/InstallTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/InstallTest.java Sun Jan  7 02:41:19 2007
@@ -15,14 +15,16 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy;
+package org.apache.ivy;
 
 import java.io.File;
 
+import org.apache.ivy.Ivy;
+import org.apache.ivy.ModuleRevisionId;
+import org.apache.ivy.matcher.PatternMatcher;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.Delete;
 
-import fr.jayasoft.ivy.matcher.PatternMatcher;
 
 import junit.framework.TestCase;
 

Copied: incubator/ivy/trunk/test/java/org/apache/ivy/ModuleRevisionIdTest.java (from r493681, incubator/ivy/trunk/test/java/fr/jayasoft/ivy/ModuleRevisionIdTest.java)
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/ModuleRevisionIdTest.java?view=diff&rev=493695&p1=incubator/ivy/trunk/test/java/fr/jayasoft/ivy/ModuleRevisionIdTest.java&r1=493681&p2=incubator/ivy/trunk/test/java/org/apache/ivy/ModuleRevisionIdTest.java&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/fr/jayasoft/ivy/ModuleRevisionIdTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/ModuleRevisionIdTest.java Sun Jan  7 02:41:19 2007
@@ -15,11 +15,13 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy;
+package org.apache.ivy;
 
 import java.util.HashMap;
 import java.util.Map;
 
+import org.apache.ivy.ModuleRevisionId;
+
 import junit.framework.TestCase;
 
 public class ModuleRevisionIdTest extends TestCase {
@@ -27,16 +29,16 @@
     public void testEncodeDecodeToString() {
         testEncodeDecodeToString(ModuleRevisionId.newInstance("org", "name", "revision"));
         testEncodeDecodeToString(ModuleRevisionId.newInstance("org", "name", ""));
-        testEncodeDecodeToString(ModuleRevisionId.newInstance("org.jayasoft", "name-post", "1.0"));
-        testEncodeDecodeToString(ModuleRevisionId.newInstance("org/jayasoft", "pre/name", "1.0-dev8/2"));
+        testEncodeDecodeToString(ModuleRevisionId.newInstance("org.apache", "name-post", "1.0"));
+        testEncodeDecodeToString(ModuleRevisionId.newInstance("org/apache", "pre/name", "1.0-dev8/2"));
         Map extraAttributes = new HashMap();
         extraAttributes.put("extra", "extravalue");
         extraAttributes.put("att/name", "att/value");
         extraAttributes.put("att.name", "att.value");
         extraAttributes.put("att<name", "att<value");
-        testEncodeDecodeToString(ModuleRevisionId.newInstance("org/jayasoft", "pre/name", "1.0-dev8/2", extraAttributes));
+        testEncodeDecodeToString(ModuleRevisionId.newInstance("org/apache", "pre/name", "1.0-dev8/2", extraAttributes));
         extraAttributes.put("nullatt", null);
-        testEncodeDecodeToString(ModuleRevisionId.newInstance("org/jayasoft", "pre/name", "1.0-dev8/2", extraAttributes));
+        testEncodeDecodeToString(ModuleRevisionId.newInstance("org/apache", "pre/name", "1.0-dev8/2", extraAttributes));
 
     }
 

Copied: incubator/ivy/trunk/test/java/org/apache/ivy/ResolveTest.java (from r493681, incubator/ivy/trunk/test/java/fr/jayasoft/ivy/ResolveTest.java)
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/ResolveTest.java?view=diff&rev=493695&p1=incubator/ivy/trunk/test/java/fr/jayasoft/ivy/ResolveTest.java&r1=493681&p2=incubator/ivy/trunk/test/java/org/apache/ivy/ResolveTest.java&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/fr/jayasoft/ivy/ResolveTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/ResolveTest.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy;
+package org.apache.ivy;
 
 import java.io.File;
 import java.util.Arrays;
@@ -29,24 +29,33 @@
 
 import junit.framework.TestCase;
 
+import org.apache.ivy.Artifact;
+import org.apache.ivy.ArtifactOrigin;
+import org.apache.ivy.DefaultArtifact;
+import org.apache.ivy.DependencyResolver;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.IvyNode;
+import org.apache.ivy.ModuleDescriptor;
+import org.apache.ivy.ModuleId;
+import org.apache.ivy.ModuleRevisionId;
+import org.apache.ivy.circular.CircularDependencyException;
+import org.apache.ivy.circular.ErrorCircularDependencyStrategy;
+import org.apache.ivy.circular.IgnoreCircularDependencyStrategy;
+import org.apache.ivy.circular.WarnCircularDependencyStrategy;
+import org.apache.ivy.report.ArtifactDownloadReport;
+import org.apache.ivy.report.ConfigurationResolveReport;
+import org.apache.ivy.report.DownloadStatus;
+import org.apache.ivy.report.ResolveReport;
+import org.apache.ivy.report.XmlReportOutputter;
+import org.apache.ivy.resolver.BasicResolver;
+import org.apache.ivy.resolver.DualResolver;
+import org.apache.ivy.resolver.FileSystemResolver;
+import org.apache.ivy.util.FileUtil;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.Delete;
 import org.xml.sax.SAXException;
 import org.xml.sax.helpers.DefaultHandler;
 
-import fr.jayasoft.ivy.circular.CircularDependencyException;
-import fr.jayasoft.ivy.circular.ErrorCircularDependencyStrategy;
-import fr.jayasoft.ivy.circular.IgnoreCircularDependencyStrategy;
-import fr.jayasoft.ivy.circular.WarnCircularDependencyStrategy;
-import fr.jayasoft.ivy.report.ArtifactDownloadReport;
-import fr.jayasoft.ivy.report.ConfigurationResolveReport;
-import fr.jayasoft.ivy.report.DownloadStatus;
-import fr.jayasoft.ivy.report.ResolveReport;
-import fr.jayasoft.ivy.report.XmlReportOutputter;
-import fr.jayasoft.ivy.resolver.BasicResolver;
-import fr.jayasoft.ivy.resolver.DualResolver;
-import fr.jayasoft.ivy.resolver.FileSystemResolver;
-import fr.jayasoft.ivy.util.FileUtil;
 
 /**
  * @author Xavier Hanin
@@ -2425,22 +2434,22 @@
         // test3 depends on test2 which depends on test
         Ivy ivy = new Ivy();
         ivy.configure(new File("test/repositories/m2/ivyconf.xml"));
-        ResolveReport report = ivy.resolve(new File("test/repositories/m2/fr/jayasoft/test3/1.0/test3-1.0.pom").toURL(),
+        ResolveReport report = ivy.resolve(new File("test/repositories/m2/org/apache/test3/1.0/test3-1.0.pom").toURL(),
                 null, new String[] {"*"}, _cache, null, true);
         assertNotNull(report);
         ModuleDescriptor md = report.getModuleDescriptor();
         assertNotNull(md);
-        ModuleRevisionId mrid = ModuleRevisionId.newInstance("fr.jayasoft", "test3", "1.0");
+        ModuleRevisionId mrid = ModuleRevisionId.newInstance("org.apache", "test3", "1.0");
         assertEquals(mrid, md.getModuleRevisionId());
         
         assertTrue(ivy.getResolvedIvyFileInCache(_cache, mrid).exists());
         
         // dependencies
-        assertTrue(ivy.getIvyFileInCache(_cache, ModuleRevisionId.newInstance("fr.jayasoft", "test2", "1.0")).exists());
-        assertTrue(ivy.getArchiveFileInCache(_cache, "fr.jayasoft", "test2", "1.0", "test2", "jar", "jar").exists());
+        assertTrue(ivy.getIvyFileInCache(_cache, ModuleRevisionId.newInstance("org.apache", "test2", "1.0")).exists());
+        assertTrue(ivy.getArchiveFileInCache(_cache, "org.apache", "test2", "1.0", "test2", "jar", "jar").exists());
 
-        assertTrue(ivy.getIvyFileInCache(_cache, ModuleRevisionId.newInstance("fr.jayasoft", "test", "1.0")).exists());
-        assertTrue(ivy.getArchiveFileInCache(_cache, "fr.jayasoft", "test", "1.0", "test", "jar", "jar").exists());
+        assertTrue(ivy.getIvyFileInCache(_cache, ModuleRevisionId.newInstance("org.apache", "test", "1.0")).exists());
+        assertTrue(ivy.getArchiveFileInCache(_cache, "org.apache", "test", "1.0", "test", "jar", "jar").exists());
     }
     
     public void testNamespaceMapping() throws Exception {
@@ -2452,7 +2461,7 @@
         assertNotNull(report);
         ModuleDescriptor md = report.getModuleDescriptor();
         assertNotNull(md);
-        ModuleRevisionId mrid = ModuleRevisionId.newInstance("jayasoft", "namespace", "1.0");
+        ModuleRevisionId mrid = ModuleRevisionId.newInstance("apache", "namespace", "1.0");
         assertEquals(mrid, md.getModuleRevisionId());
         
         assertTrue(ivy.getResolvedIvyFileInCache(_cache, mrid).exists());
@@ -2471,7 +2480,7 @@
         assertNotNull(report);
         ModuleDescriptor md = report.getModuleDescriptor();
         assertNotNull(md);
-        ModuleRevisionId mrid = ModuleRevisionId.newInstance("jayasoft", "namespace", "2.0");
+        ModuleRevisionId mrid = ModuleRevisionId.newInstance("apache", "namespace", "2.0");
         assertEquals(mrid, md.getModuleRevisionId());
         
         assertTrue(ivy.getResolvedIvyFileInCache(_cache, mrid).exists());
@@ -2493,7 +2502,7 @@
         assertNotNull(report);
         ModuleDescriptor md = report.getModuleDescriptor();
         assertNotNull(md);
-        ModuleRevisionId mrid = ModuleRevisionId.newInstance("jayasoft", "namespace", "3.0");
+        ModuleRevisionId mrid = ModuleRevisionId.newInstance("apache", "namespace", "3.0");
         assertEquals(mrid, md.getModuleRevisionId());
         
         assertTrue(ivy.getResolvedIvyFileInCache(_cache, mrid).exists());
@@ -2516,7 +2525,7 @@
         assertNotNull(report);
         ModuleDescriptor md = report.getModuleDescriptor();
         assertNotNull(md);
-        ModuleRevisionId mrid = ModuleRevisionId.newInstance("jayasoft", "namespace", "4.0");
+        ModuleRevisionId mrid = ModuleRevisionId.newInstance("apache", "namespace", "4.0");
         assertEquals(mrid, md.getModuleRevisionId());
         
         assertTrue(report.hasError());
@@ -2591,9 +2600,9 @@
                 null, new String[] {"*"}, _cache, null, false);
         assertFalse(report.hasError());
         
-        assertTrue(new File(_cache, "jayasoft/mymodule/task1/1854/ivy.xml").exists());
-        assertTrue(new File(_cache, "jayasoft/mymodule/task1/1854/mymodule-windows.jar").exists());
-        assertTrue(new File(_cache, "jayasoft/mymodule/task1/1854/mymodule-linux.jar").exists());
+        assertTrue(new File(_cache, "apache/mymodule/task1/1854/ivy.xml").exists());
+        assertTrue(new File(_cache, "apache/mymodule/task1/1854/mymodule-windows.jar").exists());
+        assertTrue(new File(_cache, "apache/mymodule/task1/1854/mymodule-linux.jar").exists());
     }
 
     public void testBranches1() throws Exception {
@@ -2662,9 +2671,9 @@
                 null, new String[] {"*"}, _cache, null, false);
         assertFalse(report.hasError());
         
-        assertTrue(_ivy.getArchiveFileInCache(_cache, "jayasoft", "A", "1.0", "a", "jar", "jar").exists());        
-        assertTrue(_ivy.getArchiveFileInCache(_cache, "jayasoft", "B", "2.0", "b", "jar", "jar").exists());        
-        assertTrue(_ivy.getArchiveFileInCache(_cache, "jayasoft", "C", "3.0", "C", "jar", "jar").exists());        
+        assertTrue(_ivy.getArchiveFileInCache(_cache, "apache", "A", "1.0", "a", "jar", "jar").exists());        
+        assertTrue(_ivy.getArchiveFileInCache(_cache, "apache", "B", "2.0", "b", "jar", "jar").exists());        
+        assertTrue(_ivy.getArchiveFileInCache(_cache, "apache", "C", "3.0", "C", "jar", "jar").exists());        
     }
 
 

Copied: incubator/ivy/trunk/test/java/org/apache/ivy/RetrieveTest.java (from r493681, incubator/ivy/trunk/test/java/fr/jayasoft/ivy/RetrieveTest.java)
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/RetrieveTest.java?view=diff&rev=493695&p1=incubator/ivy/trunk/test/java/fr/jayasoft/ivy/RetrieveTest.java&r1=493681&p2=incubator/ivy/trunk/test/java/org/apache/ivy/RetrieveTest.java&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/fr/jayasoft/ivy/RetrieveTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/RetrieveTest.java Sun Jan  7 02:41:19 2007
@@ -15,17 +15,19 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy;
+package org.apache.ivy;
 
 import java.io.File;
 import java.io.IOException;
 
+import org.apache.ivy.Ivy;
+import org.apache.ivy.ModuleDescriptor;
+import org.apache.ivy.filter.FilterHelper;
+import org.apache.ivy.report.ResolveReport;
+import org.apache.ivy.util.IvyPatternHelper;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.Delete;
 
-import fr.jayasoft.ivy.filter.FilterHelper;
-import fr.jayasoft.ivy.report.ResolveReport;
-import fr.jayasoft.ivy.util.IvyPatternHelper;
 
 import junit.framework.TestCase;
 

Copied: incubator/ivy/trunk/test/java/org/apache/ivy/SortTest.java (from r493681, incubator/ivy/trunk/test/java/fr/jayasoft/ivy/SortTest.java)
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/SortTest.java?view=diff&rev=493695&p1=incubator/ivy/trunk/test/java/fr/jayasoft/ivy/SortTest.java&r1=493681&p2=incubator/ivy/trunk/test/java/org/apache/ivy/SortTest.java&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/fr/jayasoft/ivy/SortTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/SortTest.java Sun Jan  7 02:41:19 2007
@@ -15,12 +15,17 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy;
+package org.apache.ivy;
 
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Date;
 import java.util.List;
+
+import org.apache.ivy.DefaultDependencyDescriptor;
+import org.apache.ivy.DefaultModuleDescriptor;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.ModuleRevisionId;
 
 import junit.framework.TestCase;
 

Copied: incubator/ivy/trunk/test/java/org/apache/ivy/TestPerformance.java (from r493681, incubator/ivy/trunk/test/java/fr/jayasoft/ivy/TestPerformance.java)
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/TestPerformance.java?view=diff&rev=493695&p1=incubator/ivy/trunk/test/java/fr/jayasoft/ivy/TestPerformance.java&r1=493681&p2=incubator/ivy/trunk/test/java/org/apache/ivy/TestPerformance.java&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/fr/jayasoft/ivy/TestPerformance.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/TestPerformance.java Sun Jan  7 02:41:19 2007
@@ -15,20 +15,24 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy;
+package org.apache.ivy;
 
 import java.io.File;
 import java.io.IOException;
 import java.util.Date;
 import java.util.Random;
 
+import org.apache.ivy.DefaultDependencyDescriptor;
+import org.apache.ivy.DefaultModuleDescriptor;
+import org.apache.ivy.Ivy;
+import org.apache.ivy.ModuleRevisionId;
+import org.apache.ivy.report.ResolveReport;
+import org.apache.ivy.resolver.FileSystemResolver;
+import org.apache.ivy.util.FileUtil;
+import org.apache.ivy.xml.XmlModuleDescriptorWriter;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.Delete;
 
-import fr.jayasoft.ivy.report.ResolveReport;
-import fr.jayasoft.ivy.resolver.FileSystemResolver;
-import fr.jayasoft.ivy.util.FileUtil;
-import fr.jayasoft.ivy.xml.XmlModuleDescriptorWriter;
 
 /**
  * Not a Junit test, performance depends on the machine on which the test is run...
@@ -93,7 +97,7 @@
             
             int prevCurDep = curDep;
             for (int ver = 0; ver < versions; ver++) {
-                DefaultModuleDescriptor md = new DefaultModuleDescriptor(ModuleRevisionId.newInstance("jayasoft", "mod"+nb, "1."+ver),
+                DefaultModuleDescriptor md = new DefaultModuleDescriptor(ModuleRevisionId.newInstance("apache", "mod"+nb, "1."+ver),
                         "integration", new Date());
                 
                 curDep = prevCurDep;
@@ -110,7 +114,7 @@
                         curDep++;
                     }
                     DefaultDependencyDescriptor dd = new DefaultDependencyDescriptor(md, 
-                            ModuleRevisionId.newInstance("jayasoft", "mod"+d, "latest.integration"),
+                            ModuleRevisionId.newInstance("apache", "mod"+d, "latest.integration"),
                             false, false, true);
                     dd.addDependencyConfiguration("default", "default");
                     md.addDependency(dd);

Modified: incubator/ivy/trunk/test/java/org/apache/ivy/ant/AntBuildTriggerTest.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/ant/AntBuildTriggerTest.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/org/apache/ivy/ant/AntBuildTriggerTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/ant/AntBuildTriggerTest.java Sun Jan  7 02:41:19 2007
@@ -15,14 +15,15 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.ant;
+package org.apache.ivy.ant;
 
 import java.io.File;
 
+import org.apache.ivy.Ivy;
+import org.apache.ivy.report.ResolveReport;
+import org.apache.ivy.util.FileUtil;
+
 import junit.framework.TestCase;
-import fr.jayasoft.ivy.Ivy;
-import fr.jayasoft.ivy.report.ResolveReport;
-import fr.jayasoft.ivy.util.FileUtil;
 
 public class AntBuildTriggerTest extends TestCase {
 	public void test() throws Exception {

Modified: incubator/ivy/trunk/test/java/org/apache/ivy/ant/AntCallTriggerTest.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/ant/AntCallTriggerTest.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/org/apache/ivy/ant/AntCallTriggerTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/ant/AntCallTriggerTest.java Sun Jan  7 02:41:19 2007
@@ -15,7 +15,7 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.ant;
+package org.apache.ivy.ant;
 
 import java.io.File;
 import java.io.InputStream;
@@ -24,6 +24,7 @@
 
 import junit.framework.TestCase;
 
+import org.apache.ivy.util.FileUtil;
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.BuildLogger;
 import org.apache.tools.ant.DefaultLogger;
@@ -35,7 +36,6 @@
 import org.apache.tools.ant.input.DefaultInputHandler;
 import org.apache.tools.ant.input.InputHandler;
 
-import fr.jayasoft.ivy.util.FileUtil;
 
 public class AntCallTriggerTest extends TestCase {
 	public void test() throws Exception {

Modified: incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyArtifactPropertyTest.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyArtifactPropertyTest.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyArtifactPropertyTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyArtifactPropertyTest.java Sun Jan  7 02:41:19 2007
@@ -15,12 +15,13 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.ant;
+package org.apache.ivy.ant;
 
 import java.io.File;
 
 import junit.framework.TestCase;
 
+import org.apache.ivy.ant.IvyArtifactProperty;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.Delete;
 
@@ -56,7 +57,7 @@
     }
 
     public void testSimple() throws Exception {
-        _project.setProperty("ivy.dep.file", "test/java/fr/jayasoft/ivy/ant/ivy-simple.xml");
+        _project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-simple.xml");
         _prop.setName("[module].[artifact]-[revision]");
         _prop.setValue("${cache.dir}/[module]/[artifact]-[revision].[type]");
         _prop.execute();

Modified: incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyBuildListTest.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyBuildListTest.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyBuildListTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyBuildListTest.java Sun Jan  7 02:41:19 2007
@@ -15,9 +15,11 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.ant;
+package org.apache.ivy.ant;
 
 import junit.framework.TestCase;
+
+import org.apache.ivy.ant.IvyBuildList;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.types.FileSet;
 import org.apache.tools.ant.types.Path;

Modified: incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyBuildNumberTest.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyBuildNumberTest.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyBuildNumberTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyBuildNumberTest.java Sun Jan  7 02:41:19 2007
@@ -15,12 +15,13 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.ant;
+package org.apache.ivy.ant;
 
 import java.io.File;
 
 import junit.framework.TestCase;
 
+import org.apache.ivy.ant.IvyBuildNumber;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.taskdefs.Delete;
 

Modified: incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyCacheFilesetTest.java
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyCacheFilesetTest.java?view=diff&rev=493695&r1=493681&r2=493695
==============================================================================
--- incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyCacheFilesetTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/ant/IvyCacheFilesetTest.java Sun Jan  7 02:41:19 2007
@@ -15,12 +15,13 @@
  *  limitations under the License.
  *
  */
-package fr.jayasoft.ivy.ant;
+package org.apache.ivy.ant;
 
 import java.io.File;
 
 import junit.framework.TestCase;
 
+import org.apache.ivy.ant.IvyCacheFileset;
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.DirectoryScanner;
 import org.apache.tools.ant.Project;
@@ -59,7 +60,7 @@
     }
 
     public void testSimple() throws Exception {
-        _project.setProperty("ivy.dep.file", "test/java/fr/jayasoft/ivy/ant/ivy-simple.xml");
+        _project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-simple.xml");
         _fileset.setSetid("simple-setid");
         _fileset.execute();
         Object ref = _project.getReference("simple-setid");
@@ -73,7 +74,7 @@
     }
 
     public void testEmptyConf() throws Exception {
-        _project.setProperty("ivy.dep.file", "test/java/fr/jayasoft/ivy/ant/ivy-108.xml");
+        _project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-108.xml");
         _fileset.setSetid("emptyconf-setid");
         _fileset.setConf("empty");
         _fileset.execute();
@@ -87,7 +88,7 @@
 
     public void testFailure() throws Exception {
         try {
-            _project.setProperty("ivy.dep.file", "test/java/fr/jayasoft/ivy/ant/ivy-failure.xml");
+            _project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-failure.xml");
             _fileset.setSetid("failure-setid");
             _fileset.execute();
             fail("failure didn't raised an exception with default haltonfailure setting");
@@ -98,7 +99,7 @@
 
     public void testHaltOnFailure() throws Exception {
         try {
-            _project.setProperty("ivy.dep.file", "test/java/fr/jayasoft/ivy/ant/ivy-failure.xml");
+            _project.setProperty("ivy.dep.file", "test/java/org/apache/ivy/ant/ivy-failure.xml");
             _fileset.setSetid("haltfailure-setid");
             _fileset.setHaltonfailure(false);
             _fileset.execute();
--- incubator/ivy/trunk/test/java/fr/jayasoft/ivy/DefaultDependencyDescriptorTest.java (original)
+++ incubator/ivy/trunk/test/java/org/apache/ivy/DefaultDependencyDescriptorTest.java Sun Jan  7 02:41:19 2007
@@ -16,7 +16,9 @@
  *
  */
 
-package fr.jayasoft.ivy;
+package org.apache.ivy;
+
+import org.apache.ivy.DefaultDependencyDescriptor;
 
 import junit.framework.TestCase;
 
@@ -27,7 +29,7 @@
 	}
 
 	/*
 	 * Test method for 'fr.jayasoft.ivy.DefaultDependencyDescriptor.replaceSelfFallbackPattern(String, String)'
 	 */
 	public void testReplaceSelfFallbackPattern() {
 		String replacedConf = DefaultDependencyDescriptor.replaceSelfFallbackPattern("@(default)", "compile");
@@ -42,7 +44,7 @@
 	}
 
 	/*
 	 * Test method for 'fr.jayasoft.ivy.DefaultDependencyDescriptor.replaceThisFallbackPattern(String, String)'
 	 */
 	public void testReplaceThisFallbackPattern() {
 		String replacedConf = DefaultDependencyDescriptor.replaceThisFallbackPattern("#(default)", "compile");
@@ -27,7 +29,7 @@
 
 	/*
-	 * Test method for 'fr.jayasoft.ivy.DefaultDependencyDescriptor.replaceSelfFallbackPattern(String, String)'
+	 * Test method for 'org.apache.ivy.DefaultDependencyDescriptor.replaceSelfFallbackPattern(String, String)'
 	 */
 	public void testReplaceSelfFallbackPattern() {
@@ -42,7 +44,7 @@
 
 	/*
-	 * Test method for 'fr.jayasoft.ivy.DefaultDependencyDescriptor.replaceThisFallbackPattern(String, String)'
+	 * Test method for 'org.apache.ivy.DefaultDependencyDescriptor.replaceThisFallbackPattern(String, String)'
 	 */
 	public void testReplaceThisFallbackPattern() {

Copied: incubator/ivy/trunk/test/java/org/apache/ivy/InstallTest.java (from r493681, incubator/ivy/trunk/test/java/fr/jayasoft/ivy/InstallTest.java)
URL: http://svn.apache.org/viewvc/incubator/ivy/trunk/test/java/org/apache/ivy/InstallTest.java?view=diff&rev=493695&p1=incubator/ivy/trunk/test/java/fr/jayasoft/ivy/InstallTest.java&r1=493681&p2=incubator/ivy/trunk/test/java/org/apache/ivy/InstallTest.java&r2=493695
==============================================================================